@@ -40,7 +40,7 @@
 
 extern char _STR[150];
 extern Globaldata xobjs;
-extern Clientdata areastruct;
+extern XCWindowData *areawin;
 extern Display *dpy;
 extern int *appcolors;
 
@@ -73,8 +73,7 @@ void loadlgf(int mode)
 	 sprintf(inname, "%s.lfo", _STR);
 	 ps = fopen(inname, "r");
 	 if (ps == NULL) {
-	    sprintf(_STR, "Can't open LGF file %s", inname);
-            Wprintf(_STR);
+	    Wprintf("Can't open LGF file %s", inname);
 	    return;
          }
       }
@@ -84,8 +83,7 @@ void loadlgf(int mode)
 
    if ((pdchar = strstr(inname, ".l")) != NULL) *pdchar = '\0';
 
-   sprintf(_STR, "Loaded file: %s", inname);
-   Wprintf(_STR);
+   Wprintf("Loaded file: %s", inname);
 
    /* Make sure that LGF object library has been loaded by loading it now. */
 
@@ -108,8 +106,7 @@ void loadlgf(int mode)
       return;
    }
    if (*(++pdchar) != '5') {
-      sprintf(_STR, "Don't know how to read version %c.", *pdchar);
-      Wprintf(_STR);
+      Wprintf("Don't know how to read version %c.", *pdchar);
       return;
    }
    if (fgets(temp, 149, ps) == NULL) {
@@ -127,14 +124,14 @@ void loadlgf(int mode)
 
    if (mode == 0) {
       reset(topobject, NORMAL);
-      pagereset(areastruct.page); 
+      pagereset(areawin->page); 
    }
 
    /* Set up filename and object (page) name */
 
-   xobjs.pagelist[areastruct.page]->filename = (char *) realloc (
-      xobjs.pagelist[areastruct.page]->filename, (strlen(inname) + 1) * sizeof(char));
-   strcpy(xobjs.pagelist[areastruct.page]->filename, inname);
+   xobjs.pagelist[areawin->page]->filename = (char *) realloc (
+      xobjs.pagelist[areawin->page]->filename, (strlen(inname) + 1) * sizeof(char));
+   strcpy(xobjs.pagelist[areawin->page]->filename, inname);
 
    /* If the filename has a path component, use only the root */
 
@@ -143,7 +140,7 @@ void loadlgf(int mode)
    else
       sprintf(topobject->name, "%s", inname);
 
-   renamepage(areastruct.page);
+   renamepage(areawin->page);
    printname(topobject);
 
    /* Read objects */
@@ -426,7 +423,7 @@ void loadlgf(int mode)
 			   labeldefaults(*newlabel, False, (*newinst)->position.x,
 				(*newinst)->position.y);
 			   (*newlabel)->color = DEFAULTCOLOR;
-		  	   if (areastruct.schemon){
+		  	   if (areawin->schemon){
 			      (*newlabel)->pin = LOCAL;
 			      (*newlabel)->color = LOCALPINCOLOR;
 		  	   }
@@ -451,8 +448,7 @@ void loadlgf(int mode)
 
 	       else {
 	          sscanf(lineptr, "%*d %*d %*d %*d %*d %*d %d", &hval);
-	          sprintf(_STR, "No library object %s", tmpstring);
-	          Wprintf(_STR);
+	          Wprintf("No library object %s", tmpstring);
 	       }
 
 	       for (j = 0; j < hval + 1; j++) {
@@ -497,8 +493,7 @@ void loadlgf(int mode)
 	    break;
 
 	default:
-	    sprintf(_STR, "Don't understand statement '%c'", *lineptr);
-	    Wprintf(_STR);
+	    Wprintf("Don't understand statement '%c'", *lineptr);
 	    break;
       }
    }
@@ -520,8 +515,8 @@ void loadlgf(int mode)
 	 }
       }
 
-   calcbbox(areastruct.topinstance);
-   centerview(areastruct.topinstance);
+   calcbbox(areawin->topinstance);
+   centerview(areawin->topinstance);
 
    for (i = 0; i < sigs; i++) free(signals[i]);
    free(signals);
@@ -561,8 +556,7 @@ void loadmat4(caddr_t nullval)
 	 sprintf(inname, "%s.eps", _STR);
 	 ps = fopen(inname, "r");
 	 if (ps == NULL) {
-	    sprintf(_STR, "Can't open Matlab PostScript file %s", inname);
-            Wprintf(_STR);
+	    Wprintf("Can't open Matlab PostScript file %s", inname);
 	    return;
          }
       }
@@ -572,9 +566,8 @@ void loadmat4(caddr_t nullval)
 
    if ((pdchar = strstr(_STR, ".ps")) != NULL) *pdchar = '\0';
    sprintf(topobject->name, "%s", _STR);
-   sprintf(_STR, "Loaded file: %s", inname);
-   Wprintf(_STR);
-   renamepage(areastruct.page);
+   Wprintf("Loaded file: %s", inname);
+   renamepage(areawin->page);
    printname(topobject);
 
    /* Create input string buffer */
