@@ -1834,11 +1834,11 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
       if (style & (DASHED | DOTTED)) {
          SetDashes(dpy, areawin->gc, 0, dashstring, 2);
          SetLineAttributes(dpy, areawin->gc, tmpwidth, LineOnOffDash,
-		CapButt, JoinBevel);
+		CapButt, JoinMiter);
       }
       else
          SetLineAttributes(dpy, areawin->gc, tmpwidth, LineSolid,
-		CapRound, JoinBevel);
+		(style & SQUARECAP) ? CapProjecting : CapRound, JoinMiter);
 
       /* draw the spline and close off if so specified */
       DrawLines(dpy, areawin->window, areawin->gc, pathlist,
