@@ -12,21 +12,19 @@
 #include <string.h>
 #include <stdlib.h>
 
-#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
-#endif
 
 #ifdef TCL_WRAPPER
 #include <tk.h>
 #else
-#ifndef XC_WIN32
+
 #include "Xw/Xw.h"
 #include "Xw/Form.h"
 #include "Xw/WorkSpace.h"
 #include "Xw/MenuBtn.h"
-#endif
+
 #endif
 
 /*----------------------------------------------------------------------*/
@@ -50,11 +48,11 @@
 extern Tcl_Interp *xcinterp;
 #endif
 
-#if !defined(TCL_WRAPPER)
+#ifndef TCL_WRAPPER
 
 extern Display    *dpy;
 extern GC	  hgc;
-extern Clientdata areastruct;
+extern XCWindowData *areawin;
 extern ApplicationData appdata;
 extern int 	  *appcolors;
 extern xcWidget     top;
@@ -134,7 +132,7 @@ void printhelppix()
     { XCF_Justify,	"Text Justification"},
     { XCF_Superscript,	"Text Superscript"},
     { XCF_Subscript,	"Text Subscript"},
-    { XCF_Nextfont,	"Toggle text font"},
+    { XCF_Font,		"Toggle text font"},
     { XCF_Boldfont,	"Begin Bold text"},
     { XCF_Italicfont,	"Begin Italic text"},
     { XCF_Normalfont,	"Resume normal text"},
@@ -299,8 +297,6 @@ void printhelppix()
 /* Create the help popup window	(Xt version)	*/
 /*----------------------------------------------*/
 
-#ifndef XC_WIN32
-
 void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
 {
    Arg		wargs[11];
@@ -326,8 +322,8 @@ void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
    ymax = DisplayHeight(dpy, DefaultScreen(dpy)) - 50;
 
    XtnSetArg(XtNwidth, &areawidth);
-   XtGetValues(areastruct.area, wargs, n); n = 0;
-   XtTranslateCoords(areastruct.area, (Position) (areawidth + 10), -50,
+   XtGetValues(areawin->area, wargs, n); n = 0;
+   XtTranslateCoords(areawin->area, (Position) (areawidth + 10), -50,
 	&xpos, &ypos);
 
    /*  Always direct the call to the main menu button. */
@@ -363,7 +359,7 @@ void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
 	help2, wargs, n); n = 0;
 
    XtnSetArg(XtNwidth, helpwidth);
-   XtnSetArg(XtNheight, areastruct.height);
+   XtnSetArg(XtNheight, areawin->height);
    XtnSetArg(XtNyRefWidget, cancelbutton);
    XtnSetArg(XtNyAddHeight, True);
    XtnSetArg(XtNyAttachBottom, True);
@@ -499,8 +495,6 @@ void printhelp(xcWidget hspace)
    while (XCheckWindowEvent(dpy, hwin, ExposureMask, &discard) == True);
 }
 
-#endif
-
 /*----------------------------------------------------------------------*/
 /* The TCL version assumes the existence of command "helpwindow".	*/
 /*----------------------------------------------------------------------*/
